/*  $Id: dom_document.h,v 1.8 2003/10/14 15:52:10 mbn Exp $
**
**  ClanLib Game SDK
**  Copyright (C) 2003  The ClanLib Team
**  For a total list of contributers see the file CREDITS.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Lesser General Public License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
**
*/

//! clanCore="XML"
//! header=core.h

#ifndef header_dom_document
#define header_dom_document

#if _MSC_VER > 1000
#pragma once
#endif

#include "dom_node.h"

class CL_InputSource;
class CL_OutputSource;
class CL_DomDocumentType;
class CL_DomImplementation;
class CL_DomCDATASection;
class CL_DomProcessingInstruction;
class CL_DomElement;
class CL_DomDocumentFragment;
class CL_DomComment;
class CL_DomText;
class CL_DomAttr;
class CL_DomEntityReference;
class CL_DomNodeList;
class CL_DomDocument_Generic;

class CL_DomDocument : public CL_DomNode
{
//! Construction:
public:
	CL_DomDocument();

	CL_DomDocument(CL_InputSource *input, bool delete_input = false);

	CL_DomDocument(CL_DomNode_Generic *impl);
	
	~CL_DomDocument();
	
//! Attributes:
public:
	CL_DomDocumentType get_doctype();
	
	CL_DomImplementation get_implementation();
	
	CL_DomElement get_document_element();
	
//! Operations:
public:
	CL_DomElement create_element(const std::string &tag_name);
	
	CL_DomDocumentFragment create_document_fragment();
	
	CL_DomText create_text_node(const std::string &data);
	
	CL_DomComment create_comment(const std::string &data);
	
	CL_DomCDATASection create_cdata_section(const std::string &data);
	
	CL_DomProcessingInstruction create_processing_instruction(
		const std::string &target,
		const std::string &data);
	
	CL_DomAttr create_attribute(const std::string &name);
	
	CL_DomEntityReference create_entity_reference(const std::string &name);
	
	CL_DomNodeList get_elements_by_tag_name(const std::string &tag_name);

	void load(CL_InputSource *input, bool delete_input = false);

	void save(CL_OutputSource *output, bool delete_input = false);

//! Implementation:
private:
};

#endif
