/*  $Id: dom_node.h,v 1.12 2003/10/14 15:52:10 mbn Exp $
**
**  ClanLib Game SDK
**  Copyright (C) 2003  The ClanLib Team
**  For a total list of contributers see the file CREDITS.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Lesser General Public License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
**
*/

//! clanCore="XML"
//! header=core.h

#ifndef header_dom_node
#define header_dom_node

#if _MSC_VER > 1000
#pragma once
#endif

#include <string>

class CL_DomElement;
class CL_DomAttr;
class CL_DomText;
class CL_DomCDATASection;
class CL_DomEntityReference;
class CL_DomEntity;
class CL_DomProcessingInstruction;
class CL_DomComment;
class CL_DomDocument;
class CL_DomDocumentType;
class CL_DomDocumentFragment;
class CL_DomNotation;
class CL_DomNodeList;
class CL_DomNamedNodeMap;
class CL_DomNode_Generic;

class CL_DomNode
{
//! Construction:
public:
	CL_DomNode();

	CL_DomNode(const CL_DomNode &copy);
	
	~CL_DomNode();

//! Attributes:
public:
	enum NodeType
	{
		NULL_NODE                     = 0,
		ELEMENT_NODE                  = 1,
		ATTRIBUTE_NODE                = 2,
		TEXT_NODE                     = 3,
		CDATA_SECTION_NODE            = 4,
		ENTITY_REFERENCE_NODE         = 5,
		ENTITY_NODE                   = 6,
		PROCESSING_INSTRUCTION_NODE   = 7,
		COMMENT_NODE                  = 8,
		DOCUMENT_NODE                 = 9,
		DOCUMENT_TYPE_NODE            = 10,
		DOCUMENT_FRAGMENT_NODE        = 11,
		NOTATION_NODE                 = 12
	};
	
	std::string get_node_name() const;
	
	std::string get_node_value() const;
	
	void set_node_value(const std::string &value);
	
	unsigned short get_node_type() const;
	
	CL_DomNode get_parent_node() const;
	
	CL_DomNodeList get_child_nodes() const;
	
	CL_DomNode get_first_child() const;
	
	CL_DomNode get_last_child() const;
	
	CL_DomNode get_previous_sibling() const;
	
	CL_DomNode get_next_sibling() const;
	
	CL_DomNamedNodeMap get_attributes();
	
	CL_DomDocument get_owner_document();

	bool is_null() const;

	bool is_element() const;

	bool is_attr() const;

	bool is_text() const;

	bool is_cdata_section() const;

	bool is_entity_reference() const;

	bool is_entity() const;

	bool is_processing_instruction() const;

	bool is_comment() const;

	bool is_document() const;

	bool is_document_type() const;

	bool is_document_fragment() const;

	bool is_notation() const;

	bool has_child_nodes() const;
	
//! Operations:
public:
	CL_DomNode &operator =(const CL_DomNode &copy);

	CL_DomNode insert_before(const CL_DomNode &new_child, const CL_DomNode &ref_child);
	
	CL_DomNode replace_child(const CL_DomNode &new_child, const CL_DomNode &old_child);
	
	CL_DomNode remove_child(const CL_DomNode &old_child);
	
	CL_DomNode append_child(const CL_DomNode &new_child);
	
	CL_DomNode clone_node(bool deep) const;

	CL_DomElement to_element() const;

	CL_DomAttr to_attr() const;

	CL_DomText to_text() const;

	CL_DomCDATASection to_cdata_section() const;

	CL_DomEntityReference to_entity_reference() const;

	CL_DomEntity to_entity() const;

	CL_DomProcessingInstruction to_processing_instruction() const;

	CL_DomComment to_comment() const;

	CL_DomDocument to_document() const;

	CL_DomDocumentType to_document_type() const;

	CL_DomDocumentFragment to_document_fragment() const;

	CL_DomNotation to_notation() const;

	CL_DomNode named_item(const std::string &name) const;

//! Implementation:
protected:
	CL_DomNode(CL_DomDocument &doc, unsigned short node_type);

	CL_DomNode(CL_DomNode_Generic *impl);

	CL_DomNode_Generic *impl;

	friend class CL_DomDocument;
};

#endif
