/*  $Id: menudata.h,v 1.25 2003/10/14 15:52:10 mbn Exp $
**
**  ClanLib Game SDK
**  Copyright (C) 2003  The ClanLib Team
**  For a total list of contributers see the file CREDITS.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Lesser General Public License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
**
*/

//! clanGUI="Controls"
//! header=gui.h

#ifndef header_menudata
#define header_menudata

#if _MSC_VER > 1000
#pragma once
#endif

class CL_Component;
class CL_PopupMenu;
class CL_MenuData_Generic;
class CL_MenuNode;

//: MenuData	
class CL_MenuData
{
//! Construction:
public:
	//: The menunode constructor.
	//- <p>Not to be constructed by user - use insert_item() instead, which
	//- creates a CL_MenuData.</p>
	CL_MenuData(CL_PopupMenu *popupmenu);
	
	virtual ~CL_MenuData();

//! Attributes:
public:
	//: Returns all components in this node.
	const std::list<CL_MenuNode *> &get_items() const;

//! Operations:
public:
	//: Inserts an item at index. 
	//- <p>If index is negative, text is inserted at the end of the list.
	//- Returns the node of the item.</p>
	CL_MenuNode *insert_item(const std::string &text, int index = -1);

	//: Inserts an item at index, with a submenu.
	//- <p>If index is negative, text is inserted at the end of the list.</p>
	//return: the node of the item.
	CL_MenuNode *insert_item(const std::string &text, CL_PopupMenu *submenu, int index = -1);

	//: Inserts an item (uses any type of component) at index. 
	//- <p>If index is negative, text is inserted at the end of the list.
	//- Set delete_component to true if you want the component to be deleted when
	//- this node gets deleted.</p>
	//return: the node of the item.
	CL_MenuNode *insert_item(CL_Component *component, bool delete_component = false, int index = -1);

	//: Inserts an item (uses any type of component) at index, with a submenu.
	//- <p>If index is negative, text is inserted at the end of the list.
	//- Set delete_component to true if you want the component to be deleted when
	//- this node gets deleted.</p>
	//return: the node of the item.
	CL_MenuNode *insert_item(CL_Component *component, CL_PopupMenu *submenu, bool delete_component = false, int index = -1);

	//: Deletes all items.
	void clear();

//! Implementation:
private:
	CL_MenuData(const CL_MenuData &copy) { return; } // disallow copy construction.
	CL_MenuData_Generic *impl;
};

#endif
