/*  $Id: menunode.h,v 1.6 2003/10/14 15:52:10 mbn Exp $
**
**  ClanLib Game SDK
**  Copyright (C) 2003  The ClanLib Team
**  For a total list of contributers see the file CREDITS.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Lesser General Public License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
**
*/

//! clanGUI="Controls"
//! header=gui.h

#ifndef header_menunode
#define header_menunode

#if _MSC_VER > 1000
#pragma once
#endif

#include <string>

class CL_Point;
class CL_MenuNode_Generic;
class CL_Component;
class CL_PopupMenu;
class CL_Component;

//: MenuItem
class CL_MenuNode
{
//! Construction:
public:
	CL_MenuNode(CL_PopupMenu *submenu);
	
	virtual ~CL_MenuNode();

//! Attributes:
public:
	//: Returns true if node is selected
	bool is_selected() const;
	
	//: Return true if node has sub-items
	bool has_submenu() const;

	//: Returns the attaches userdata, if any.
	void *get_userdata() const;

	//: Returns the CL_Component this node uses.
	CL_Component *get_component() const;

//! Operations:
public:
	//: Sets/changes a new component for the node.
	//- <p>Mostly used when add(CL_Component *) is used with a NULL parameter.
	//- Set delete_component to true if you want the component to be deleted when
	//- this node gets deleted.</p>
	void set_component(CL_Component *component, bool delete_component = false);

	//: Select this node.
	void set_selected(bool select = true);

	//: Attaches userdata to node.
	void set_userdata(void *data);

//! Implementation:
private:
	CL_MenuNode(const CL_MenuNode &copy) { return; } // disallow copy construction.
	CL_MenuNode_Generic *impl;
};

#endif
