/*  $Id: treeitem.h,v 1.5 2003/10/14 15:52:11 mbn Exp $
**
**  ClanLib Game SDK
**  Copyright (C) 2003  The ClanLib Team
**  For a total list of contributers see the file CREDITS.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Lesser General Public License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
**
*/

//! clanGUI="Controls"
//! header=gui.h

#ifndef header_treeitem
#define header_treeitem

#if _MSC_VER > 1000
#pragma once
#endif

#include "component.h"

class CL_TreeItem_Generic;
class CL_TreeNode;

//: TreeView_Item component
class CL_TreeItem : public CL_Component
{
//! Construction:
public:
	//: TreeView Item Constructor
	CL_TreeItem(
		CL_TreeNode *node,
		CL_Component *parent,
		CL_StyleManager *style = NULL);

	//: TreeView Item Constructor
	CL_TreeItem(
		CL_TreeNode *node,
		const std::string &text,
		CL_Component *parent,
		CL_StyleManager *style = NULL);

	//: TreeView Item Destructor
	virtual ~CL_TreeItem();

//! Attributes:
public:
	//: Returns the item label.
	//return: The item label.
	const std::string &get_text() const;

	//: Returns the TreeView node this component is used in.
	CL_TreeNode *get_node() const;

//! Operations:
public:
	//: Sets the item label.
	//param text: The item label.
	void set_text(const std::string &text);

//! Signals:
public:
	//: This signal is emitted when the item is clicked on.
	CL_Signal_v0 &sig_clicked();

//! Implementation:
private:
	CL_TreeItem(const CL_TreeItem &copy) : CL_Component(NULL, NULL) { return; } // disallow copy construction.
	CL_TreeItem_Generic *impl;
};

#endif
