/*  $Id: treenode.h,v 1.6 2003/10/14 15:52:11 mbn Exp $
**
**  ClanLib Game SDK
**  Copyright (C) 2003  The ClanLib Team
**  For a total list of contributers see the file CREDITS.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Lesser General Public License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
**
*/

//! clanGUI="Controls"
//! header=gui.h

#ifndef header_treenode
#define header_treenode

#if _MSC_VER > 1000
#pragma once
#endif

#include "../Core/Math/point.h"
#include <string>

class CL_TreeView;
class CL_TreeNode_Generic;
class CL_Component;

//: TreeView node
class CL_TreeNode
{
//! Construction:
public:
	//: The treenode constructor.
	//- <p>Not to be constructed by user - use insert_item() instead, which
	//- creates a CL_TreeNode.</p>
	CL_TreeNode(CL_TreeView *root_tree);
	
	virtual ~CL_TreeNode();

//! Attributes:
public:
	//: Returns true if node is selected
	bool is_selected() const;
	
	//: Return true if node is collapsed
	bool is_collapsed() const;

	//: Return true if node has sub-items
	bool has_children() const;

	//: Returns the attaches userdata, if any.
	void *get_userdata() const;

	//: Returns the CL_Component this node uses.
	CL_Component *get_component() const;

//! Operations:
public:
	//: Inserts an item at index. 
	//- <p>If index is negative, text is inserted at the end of the list.</p>
	//return: the node of the item.
	CL_TreeNode *insert_item(const std::string &text, int index = -1);

	//: Inserts an item (uses any type of component) at index. 
	//- <p>If index is negative, text is inserted at the end of the list.
	//- Set delete_component to true if you want the component to be deleted when
	//- this node gets deleted.</p>
	//return: the node of the item.
	CL_TreeNode *insert_item(CL_Component *component, bool delete_component = false, int index = -1);

	//: Sets/changes a new component for the node.
	//- <p>Mostly used when add(CL_Component *) is used with a NULL parameter.
	//- Set delete_component to true if you want the component to be deleted when
	//- this node gets deleted.</p>
	void set_component(CL_Component *component, bool delete_component = false);

	//: Collapse this node.
	void set_collapsed(bool collapse = true);
	
	//: Select this node.
	void set_selected(bool select = true);

	//: Select any of the children nodes.
	void set_selected(CL_TreeNode *node, bool select = true);

	//: Deselects current selected item.
	void clear_selection();

	//: Inverts the selection.
	//: Works only in Multi selection mode.
	void invert_selection();

	//: Deletes all items in the tree.
	void clear();

	//: Attaches userdata to node.
	void set_userdata(void *data);

	void draw_nodes(CL_Point &point);
	
//! Implementation:
private:
	CL_TreeNode(const CL_TreeNode &copy) { return; } // disallow copy construction.
	CL_TreeNode_Generic *impl;
};

#endif
