/*  $Id: browse_client.h,v 1.8 2003/10/14 15:52:11 mbn Exp $
**
**  ClanLib Game SDK
**  Copyright (C) 2003  The ClanLib Team
**  For a total list of contributers see the file CREDITS.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Lesser General Public License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
**
*/

//! clanNetwork="Browsing"
//! header=network.h

#ifndef header_browse_client
#define header_browse_client

#if _MSC_VER > 1000
#pragma once
#endif

#include "../../signals.h"
#include <string>

class CL_IPAddress;
class CL_BrowseClient_Generic;
class CL_NetPacket;

//: Browse client to a browse master.
//- <p>The browse client is used to connect to a browse master and get a list of registered
//- applications. Using this information, the application can generate a list of available
//- servers that the user can connect to.</p>
class CL_BrowseClient
{
//! Construction:
public:
	//: Construct browse client to browse applications with the specified identifier.
	CL_BrowseClient(const std::string &app_id);

	//: Browse Client Destructor
	virtual ~CL_BrowseClient();

//! Operations:
public:
	//: Connect to browse master and start downloading getting browse list.
	void connect(const CL_IPAddress &browse_master);

	//: Broadcast browse query on local area network for browse servers on the specified port.
	void broadcast(const std::string &port);

//! Signals:
public:
	//: Signal that is called when the browse client is notified about a server addition.
	CL_Signal_v2<const CL_IPAddress &, CL_NetPacket &> &sig_server_added();

	//: Signal that is called when the browse client is notified about a server update.
	CL_Signal_v2<const CL_IPAddress &, CL_NetPacket &> &sig_server_updated();

	//: Signal that is called when the browse client is notified about a server removal.
	CL_Signal_v1<const CL_IPAddress &> &sig_server_removed();

//! Implementation:
private:
	CL_BrowseClient_Generic *impl;
};

#endif
