/*  $Id: browse_server.h,v 1.7 2003/10/14 15:52:11 mbn Exp $
**
**  ClanLib Game SDK
**  Copyright (C) 2003  The ClanLib Team
**  For a total list of contributers see the file CREDITS.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Lesser General Public License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
**
*/

//! clanNetwork="Browsing"
//! header=network.h

#ifndef header_browse_server
#define header_browse_server

#if _MSC_VER > 1000
#pragma once
#endif

#include <string>

class CL_IPAddress;
class CL_BrowseServer_Generic;
class CL_NetPacket;

//: Browse server to a browse master.
//- <p>The browse service is used to register a server on a browse master.</p>
class CL_BrowseServer
{
//! Construction:
public:
	//: Setup a browsing server for an application with the specified identifier
	//: and the game server running on the specified server address.
	CL_BrowseServer(
		const std::string &app_id,
		const CL_IPAddress &server_address);

	//: Disconnect from browse master.
	virtual ~CL_BrowseServer();

//! Attributes:
public:

//! Operations:
public:
	//: Set/change the server description on the browse master.
	void set_description(const CL_NetPacket &description);

	//: Connect to browser master and register ourselves.
	void connect(const CL_IPAddress &browse_master);

	//: Listen for local area network browse queries on the specified port.
	void listen(const std::string &port);

//! Implementation:
private:
	CL_BrowseServer_Generic *impl;
};

#endif
